@@ -145,6 +145,12 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_6_11(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x60f00
+#  define KIOCORE_DEPRECATED_VERSION_6_15(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_6_15(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_6(minor, text)      KIOCORE_DEPRECATED_VERSION_6_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION(major, minor, text) KIOCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
